@@ -11,7 +11,7 @@ logger = logging.getLogger(__name__)
 
 STATUS = "status"
 DATA = "data"
-ERROR_MESSAGE = "message"
+MESSAGE = "message"
 SUCCESS = "SUCCESS"
 FAILED = "FAILED"
 
@@ -70,7 +70,7 @@ def connect():
                                          user_s3_bucket=_user_s3_bucket)
             return athena_client
         else:
-            print(response[ERROR_MESSAGE])
+            print(response[MESSAGE])
 
     except requests.exceptions.HTTPError:
         print("Http error occurred")
@@ -107,7 +107,7 @@ class AthenaClient:
                     response_as_df = pd.DataFrame.from_dict(response[DATA])
                     return response_as_df
             else:
-                print(response[ERROR_MESSAGE])
+                print(response[MESSAGE])
 
         except requests.exceptions.HTTPError:
             print("Http error occurred")
@@ -134,7 +134,7 @@ class AthenaClient:
                     response_as_df = pd.DataFrame.from_dict(response[DATA])
                     return response_as_df
             else:
-                print(response[ERROR_MESSAGE])
+                print(response[MESSAGE])
 
         except requests.exceptions.HTTPError:
             print("Http error occurred")
@@ -162,7 +162,7 @@ class AthenaClient:
                     response_as_df = pd.DataFrame.from_dict(response[DATA])
                     return response_as_df
             else:
-                print(response[ERROR_MESSAGE])
+                print(response[MESSAGE])
 
         except requests.exceptions.HTTPError:
             print("Http error occurred")
@@ -200,7 +200,7 @@ class AthenaClient:
                         results = pd.DataFrame.from_dict(response[DATA])
                     return results
             else:
-                print(response[ERROR_MESSAGE])
+                print(response[MESSAGE])
 
         except requests.exceptions.HTTPError:
             print("Http error occurred")
@@ -222,9 +222,10 @@ class AthenaClient:
                               cookies=self._cookie)
             response = r.json()
             if response[STATUS] == SUCCESS:
+                print(response[MESSAGE])
                 return response[DATA]
             else:
-                print(response[ERROR_MESSAGE])
+                print(response[MESSAGE])
 
         except requests.exceptions.HTTPError:
             print("Http error occurred")
